from hawkdata.fund import fund_basic as fb
fund_basic = fb
from hawkdata.fund import fund_market_perf as fmp
fund_market_perf = fmp

from hawkdata.stock import stock_us as su
stock_us = su

from hawkdata.bond import cbond as cb
cbond = cb

from hawkdata.macro import china_gdp as cgdp
china_gdp = cgdp
from hawkdata.macro import china_cpi as ccpi
china_cpi = ccpi

from hawkdata.index import china_index as cidx
china_index = cidx
from hawkdata.index import global_index as gloidx
global_index = gloidx
